==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/menu/rgss/Scene_Map_update.rb <==
#==============================================================================
#  Scene_Map#update
#------------------------------------------------------------------------------
# j[ĂяoL[̕ύX
# Copyright (C) 2005 fukuyama
#==============================================================================

class Scene_Map
  #--------------------------------------------------------------------------
  #  t[XV
  #--------------------------------------------------------------------------
  def update
    # [v
    loop do
      # }bvAC^v^AvC[̏ɍXV
      # (̍XV́ACxgsĂƂ
      #  vC[Ɉuړ@^ȂȂǂ̗Rŏdv)
      $game_map.update
      $game_system.map_interpreter.update
      $game_player.update
      # VXe (^C}[)AʂXV
      $game_system.update
      $game_screen.update
      # vC[̏ꏊړłȂ΃[v𒆒f
      unless $game_temp.player_transferring
        break
      end
      # ꏊړs
      transfer_player
      # gWV̏ꍇA[v𒆒f
      if $game_temp.transition_processing
        break
      end
    end
    # XvCgZbgXV
    @spriteset.update
    # bZ[WEBhEXV
    @message_window.update
    # Q[I[o[̏ꍇ
    if $game_temp.gameover
      # Q[I[o[ʂɐ؂ւ
      $scene = Scene_Gameover.new
      return
    end
    # ^Cgʂɖ߂ꍇ
    if $game_temp.to_title
      # ^Cgʂɐ؂ւ
      $scene = Scene_Title.new
      return
    end
    # gWV̏ꍇ
    if $game_temp.transition_processing
      # gWVtONA
      $game_temp.transition_processing = false
      # gWVs
      if $game_temp.transition_name == ""
        Graphics.transition(20)
      else
        Graphics.transition(40, "Graphics/Transitions/" +
          $game_temp.transition_name)
      end
    end
    # bZ[WEBhE\̏ꍇ
    if $game_temp.message_window_showing
      return
    end
    # GJEg JEg 0 ŁAGJEgXgł͂Ȃꍇ
    if $game_player.encounter_count == 0 and $game_map.encounter_list != []
      # CxgsGJEg֎~łȂ
      unless $game_system.map_interpreter.running? or
             $game_system.encounter_disabled
        # g[v
        n = rand($game_map.encounter_list.size)
        troop_id = $game_map.encounter_list[n]
        # g[vLȂ
        if $data_troops[troop_id] != nil
          # ogĂяotOZbg
          $game_temp.battle_calling = true
          $game_temp.battle_troop_id = troop_id
          $game_temp.battle_can_escape = true
          $game_temp.battle_can_lose = false
          $game_temp.battle_proc = nil
        end
      end
    end
    # C {^ꂽꍇ
    if Input.trigger?(Input::C)
      # Cxgsj[֎~łȂ
      unless $game_system.map_interpreter.running? or
             $game_system.menu_disabled
        # j[ĂяotO SE ttOZbg
        $game_temp.menu_calling = true
        $game_temp.menu_beep = true
      end
    end
    # fobO[h ON  F9 L[Ăꍇ
    if $DEBUG and Input.press?(Input::F9)
      # fobOĂяotOZbg
      $game_temp.debug_calling = true
    end
    # vC[̈ړł͂Ȃꍇ
    unless $game_player.moving?
      # eʂ̌Ăяos
      if $game_temp.battle_calling
        call_battle
      elsif $game_temp.shop_calling
        call_shop
      elsif $game_temp.name_calling
        call_name
      elsif $game_temp.menu_calling
        call_menu
      elsif $game_temp.save_calling
        call_save
      elsif $game_temp.debug_calling
        call_debug
      end
    end
  end
end

==> DQScriptsDemo_0_3_1.zip: DQScriptsDemo_0_3_1/rgss-lib/dq/menu/rgss/Scene_Map_update.rb <==
#==============================================================================
#  Scene_Map#update
#------------------------------------------------------------------------------
# j[ĂяoL[̕ύX
# Copyright (C) 2005 fukuyama
#==============================================================================

class Scene_Map

  #--------------------------------------------------------------------------
  #  t[XV
  #--------------------------------------------------------------------------
  def update
    # [v
    loop do
      # }bvAC^v^AvC[̏ɍXV
      # (̍XV́ACxgsĂƂ
      #  vC[Ɉuړ@^ȂȂǂ̗Rŏdv)
      $game_map.update
      $game_system.map_interpreter.update
      $game_player.update
      # VXe (^C}[)AʂXV
      $game_system.update
      $game_screen.update
      # vC[̏ꏊړłȂ΃[v𒆒f
      unless $game_temp.player_transferring
        break
      end
      @message_window.dispose
      @message_window = Window_Message.new
      # ꏊړs
      transfer_player
      # gWV̏ꍇA[v𒆒f
      if $game_temp.transition_processing
        break
      end
    end
    # XvCgZbgXV
    @spriteset.update
    # bZ[WEBhEXV
    @message_window.update
    # Q[I[o[̏ꍇ
    if $game_temp.gameover
      # Q[I[o[ʂɐ؂ւ
      $scene = Scene_Gameover.new
      return
    end
    # ^Cgʂɖ߂ꍇ
    if $game_temp.to_title
      # ^Cgʂɐ؂ւ
      $scene = Scene_Title.new
      return
    end
    # gWV̏ꍇ
    if $game_temp.transition_processing
      # gWVtONA
      $game_temp.transition_processing = false
      # gWVs
      if $game_temp.transition_name == ""
        Graphics.transition(20)
      else
        Graphics.transition(40, "Graphics/Transitions/" +
        $game_temp.transition_name)
      end
    end
    # bZ[WEBhE\̏ꍇ
    if $game_temp.message_window_showing or @message_window.parallel
      return
    end
    # GJEg JEg 0 ŁAGJEgXgł͂Ȃꍇ
    if $game_player.encounter_count == 0 and $game_map.encounter_list != []
      # CxgsGJEg֎~łȂ
      unless $game_system.map_interpreter.running? or
        $game_system.encounter_disabled
        # g[v
        n = rand($game_map.encounter_list.size)
        troop_id = $game_map.encounter_list[n]
        # g[vLȂ
        if $data_troops[troop_id] != nil
          # ogĂяotOZbg
          $game_temp.battle_calling = true
          $game_temp.battle_troop_id = troop_id
          $game_temp.battle_can_escape = true
          $game_temp.battle_can_lose = false
          $game_temp.battle_proc = nil
        end
      end
    end
    # Cj[{^ꂽꍇ
    if ::DQ::DEFAULT_MAIN_MENU_KEY.any? {|k|Input.trigger?(k)}
      # Cxgsj[֎~łȂ
      unless $game_system.map_interpreter.running? or $game_system.menu_disabled
        # j[ĂяotO SE ttOZbg
        $game_temp.menu_calling = true
        $game_temp.menu_beep = true
      end
    end
    # fobO[h ON  F9 L[Ăꍇ
    if $DEBUG and Input.press?(Input::F9)
      # fobOĂяotOZbg
      $game_temp.debug_calling = true
    end
    # vC[̈ړł͂Ȃꍇ
    unless $game_player.moving?
      # NĂCxg̊mF
      # FIXME Cxg̋Nƃj[̎st[ŋNƗNĂ܂̂Ώ
      event_starting = false
      unless $game_system.map_interpreter.running?
        $game_map.events.values.each do |event|
          # gK[ (0:{^A1:vC[ڐGA2:CxgڐGA3:sA4:񏈗)
          if event.starting and event.trigger <= 2
            event_starting = true
            break
          end
        end
      end
      # eʂ̌Ăяos
      if $game_temp.battle_calling
        call_battle
      elsif $game_temp.shop_calling
        call_shop
      elsif $game_temp.name_calling
        call_name
      elsif $game_temp.menu_calling
        unless event_starting
          call_menu
        else
          $game_temp.menu_calling = false
          $game_temp.menu_beep = false
        end
      elsif $game_temp.save_calling
        call_save
      elsif $game_temp.debug_calling
        call_debug
      end
    end
  end
end
